Crate httpdir

Crate httpdir 

This library provides an Iterator to crawl the list of files available through Index of HTTP url.

Here is an example usage:

use url::Url;
let url = Url::parse("http://localhost/logs/").unwrap();
let files: Vec<Url> = httpdir::list(url)?;

Or using the iterator:

for file in httpdir::Crawler::new().walk(url) {
   let file: Url = file?;
}

Structs

Crawler
The state of the crawler, created calling Crawler::new().

Functions

http_list
List the files and directories of a single url.
list
Helper function to walk a single url and list all the available files.